@@ -31,7 +31,7 @@ mod tests {
     #[test_case(Rule::UnnecessaryMap, Path::new("C417.py"); "C417")]
 
     fn rules(rule_code: Rule, path: &Path) -> Result<()> {
-        let snapshot = format!("{}_{}", rule_code.code(), path.to_string_lossy());
+        let snapshot = format!("{}_{}", rule_code.noqa_code(), path.to_string_lossy());
         let diagnostics = test_path(
             Path::new("flake8_comprehensions").join(path).as_path(),
             &settings::Settings::for_rule(rule_code),
