@@ -16,7 +16,7 @@ pub struct Comment<'a> {
 
 /// Collect all comments in an import block.
 pub fn collect_comments<'a>(range: &Range, locator: &'a Locator) -> Vec<Comment<'a>> {
-    let contents = locator.slice_source_code_range(range);
+    let contents = locator.slice(range);
     lexer::make_tokenizer_located(contents, range.location)
         .flatten()
         .filter_map(|(start, tok, end)| {
