@@ -80,9 +80,9 @@ fn generate_fix(
         stderr
     };
     let mut contents = String::from("capture_output=True");
-    if let Some(middle) = extract_middle(
-        locator.slice_source_code_range(&Range::new(first.end_location.unwrap(), last.location)),
-    ) {
+    if let Some(middle) =
+        extract_middle(locator.slice(&Range::new(first.end_location.unwrap(), last.location)))
+    {
         if middle.multi_line {
             let Some(indent) = indentation(locator, first) else {
                 return None;
