@@ -96,6 +96,9 @@ pub struct CheckArgs {
     /// Output serialization format for violations.
     #[arg(long, value_enum, env = "RUFF_FORMAT")]
     pub format: Option<SerializationFormat>,
+    /// The minimum Python version that should be supported.
+    #[arg(long)]
+    pub target_version: Option<PythonVersion>,
     /// Path to the `pyproject.toml` or `ruff.toml` file to use for
     /// configuration.
     #[arg(long, conflicts_with = "isolated")]
@@ -106,7 +109,8 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
-        help_heading = "Rule selection"
+        help_heading = "Rule selection",
+        hide_possible_values = true
     )]
     pub select: Option<Vec<RuleSelector>>,
     /// Comma-separated list of rule codes to disable.
@@ -114,7 +118,8 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
-        help_heading = "Rule selection"
+        help_heading = "Rule selection",
+        hide_possible_values = true
     )]
     pub ignore: Option<Vec<RuleSelector>>,
     /// Like --select, but adds additional rule codes on top of the selected
@@ -123,7 +128,8 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
-        help_heading = "Rule selection"
+        help_heading = "Rule selection",
+        hide_possible_values = true
     )]
     pub extend_select: Option<Vec<RuleSelector>>,
     /// Like --ignore. (Deprecated: You can just use --ignore instead.)
@@ -161,7 +167,8 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
-        help_heading = "Rule selection"
+        help_heading = "Rule selection",
+        hide_possible_values = true
     )]
     pub fixable: Option<Vec<RuleSelector>>,
     /// List of rule codes to treat as ineligible for autofix. Only applicable
@@ -170,7 +177,8 @@ pub struct CheckArgs {
         long,
         value_delimiter = ',',
         value_name = "RULE_CODE",
-        help_heading = "Rule selection"
+        help_heading = "Rule selection",
+        hide_possible_values = true
     )]
     pub unfixable: Option<Vec<RuleSelector>>,
     /// Respect file exclusions via `.gitignore` and other standard ignore
@@ -193,9 +201,6 @@ pub struct CheckArgs {
     force_exclude: bool,
     #[clap(long, overrides_with("force_exclude"), hide = true)]
     no_force_exclude: bool,
-    /// The minimum Python version that should be supported.
-    #[arg(long, help_heading = "Rule configuration", hide = true)]
-    pub target_version: Option<PythonVersion>,
     /// Set the line-length for length-associated rules and automatic
     /// formatting.
     #[arg(long, help_heading = "Rule configuration", hide = true)]
