@@ -53,9 +53,9 @@ struct ExpandedMessage<'a> {
 }
 
 #[derive(Serialize)]
-struct ExpandedStatistics<'a> {
+struct ExpandedStatistics {
     count: usize,
-    code: &'a str,
+    code: String,
     message: String,
     fixable: bool,
 }
@@ -67,7 +67,7 @@ impl Serialize for SerializeRuleAsCode<'_> {
     where
         S: serde::Serializer,
     {
-        serializer.serialize_str(self.0.code())
+        serializer.serialize_str(&self.0.noqa_code().to_string())
     }
 }
 
@@ -221,7 +221,7 @@ impl Printer {
                             message.kind.body()
                         ));
                         let mut case = TestCase::new(
-                            format!("org.ruff.{}", message.kind.rule().code()),
+                            format!("org.ruff.{}", message.kind.rule().noqa_code()),
                             status,
                         );
                         let file_path = Path::new(filename);
@@ -313,14 +313,14 @@ impl Printer {
                         ":",
                         message.location.column(),
                         ":",
-                        message.kind.rule().code(),
+                        message.kind.rule().noqa_code(),
                         message.kind.body(),
                     );
                     writeln!(
                         stdout,
                         "::error title=Ruff \
                          ({}),file={},line={},col={},endLine={},endColumn={}::{}",
-                        message.kind.rule().code(),
+                        message.kind.rule().noqa_code(),
                         message.filename,
                         message.location.row(),
                         message.location.column(),
@@ -341,9 +341,9 @@ impl Printer {
                             .iter()
                             .map(|message| {
                                 json!({
-                                    "description": format!("({}) {}", message.kind.rule().code(), message.kind.body()),
+                                    "description": format!("({}) {}", message.kind.rule().noqa_code(), message.kind.body()),
                                     "severity": "major",
-                                    "fingerprint": message.kind.rule().code(),
+                                    "fingerprint": message.kind.rule().noqa_code().to_string(),
                                     "location": {
                                         "path": message.filename,
                                         "lines": {
@@ -366,7 +366,7 @@ impl Printer {
                         "{}:{}: [{}] {}",
                         relativize_path(Path::new(&message.filename)),
                         message.location.row(),
-                        message.kind.rule().code(),
+                        message.kind.rule().noqa_code(),
                         message.kind.body(),
                     );
                     writeln!(stdout, "{label}")?;
@@ -394,7 +394,7 @@ impl Printer {
         let statistics = violations
             .iter()
             .map(|rule| ExpandedStatistics {
-                code: rule.code(),
+                code: rule.noqa_code().to_string(),
                 count: diagnostics
                     .messages
                     .iter()
@@ -538,7 +538,7 @@ impl Display for CodeAndBody<'_> {
             write!(
                 f,
                 "{code} {autofix}{body}",
-                code = self.0.kind.rule().code().red().bold(),
+                code = self.0.kind.rule().noqa_code().to_string().red().bold(),
                 autofix = format_args!("[{}] ", "*".cyan()),
                 body = self.0.kind.body(),
             )
@@ -546,7 +546,7 @@ impl Display for CodeAndBody<'_> {
             write!(
                 f,
                 "{code} {body}",
-                code = self.0.kind.rule().code().red().bold(),
+                code = self.0.kind.rule().noqa_code().to_string().red().bold(),
                 body = self.0.kind.body(),
             )
         }
@@ -589,6 +589,7 @@ fn print_message<T: Write>(
         } else {
             vec![]
         };
+        let label = message.kind.rule().noqa_code().to_string();
         let snippet = Snippet {
             title: Some(Annotation {
                 label: None,
@@ -601,7 +602,7 @@ fn print_message<T: Write>(
                 source: &source.contents,
                 line_start: message.location.row(),
                 annotations: vec![SourceAnnotation {
-                    label: message.kind.rule().code(),
+                    label: &label,
                     annotation_type: AnnotationType::Error,
                     range: source.range,
                 }],
@@ -656,7 +657,7 @@ fn print_fixed<T: Write>(stdout: &mut T, fixed: &FxHashMap<String, FixTable>) ->
             writeln!(
                 stdout,
                 "    {count:>num_digits$} × {} ({})",
-                rule.code().red().bold(),
+                rule.noqa_code().to_string().red().bold(),
                 rule.as_ref(),
             )?;
         }
@@ -694,6 +695,7 @@ fn print_grouped_message<T: Write>(
         } else {
             vec![]
         };
+        let label = message.kind.rule().noqa_code().to_string();
         let snippet = Snippet {
             title: Some(Annotation {
                 label: None,
@@ -706,7 +708,7 @@ fn print_grouped_message<T: Write>(
                 source: &source.contents,
                 line_start: message.location.row(),
                 annotations: vec![SourceAnnotation {
-                    label: message.kind.rule().code(),
+                    label: &label,
                     annotation_type: AnnotationType::Error,
                     range: source.range,
                 }],
