@@ -1,6 +1,7 @@
 pub mod ast;
 pub mod filesystem;
 pub mod imports;
-pub mod lines;
+pub mod logical_lines;
 pub mod noqa;
+pub mod physical_lines;
 pub mod tokens;
