@@ -15,6 +15,11 @@ pub(crate) fn get_redirect(code: &str) -> Option<(&'static str, &'static str)> {
 
 static REDIRECTS: Lazy<HashMap<&'static str, &'static str>> = Lazy::new(|| {
     HashMap::from_iter([
+        ("C", "C4"),
+        ("C9", "C90"),
+        ("T", "T10"),
+        ("T1", "T10"),
+        ("T2", "T20"),
         // TODO(charlie): Remove by 2023-02-01.
         ("R", "RET"),
         ("R5", "RET5"),
