@@ -1,5 +1,6 @@
+use ruff_macros::{define_violation, derive_message_formats};
 use rustc_hash::FxHashSet;
-use rustpython_ast::{Comprehension, Expr, ExprContext, ExprKind, Stmt, StmtKind};
+use rustpython_parser::ast::{Comprehension, Expr, ExprContext, ExprKind, Stmt, StmtKind};
 
 use crate::ast::helpers::collect_arg_names;
 use crate::ast::types::{Node, Range};
@@ -7,7 +8,20 @@ use crate::ast::visitor;
 use crate::ast::visitor::Visitor;
 use crate::checkers::ast::Checker;
 use crate::registry::Diagnostic;
-use crate::violations;
+use crate::violation::Violation;
+
+define_violation!(
+    pub struct FunctionUsesLoopVariable {
+        pub name: String,
+    }
+);
+impl Violation for FunctionUsesLoopVariable {
+    #[derive_message_formats]
+    fn message(&self) -> String {
+        let FunctionUsesLoopVariable { name } = self;
+        format!("Function definition does not bind loop variable `{name}`")
+    }
+}
 
 #[derive(Default)]
 struct LoadedNamesVisitor<'a> {
@@ -260,7 +274,7 @@ where
                 if !checker.flake8_bugbear_seen.contains(&expr) {
                     checker.flake8_bugbear_seen.push(expr);
                     checker.diagnostics.push(Diagnostic::new(
-                        violations::FunctionUsesLoopVariable {
+                        FunctionUsesLoopVariable {
                             name: name.to_string(),
                         },
                         range,
