@@ -1,11 +1,48 @@
-use rustpython_ast::{Expr, ExprKind, Keyword, Stmt, StmtKind, Withitem};
+use ruff_macros::{define_violation, derive_message_formats};
+use rustpython_parser::ast::{Expr, ExprKind, Keyword, Stmt, StmtKind, Withitem};
 
 use super::helpers::is_empty_or_null_string;
 use crate::ast::helpers::{format_call_path, to_call_path};
 use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
 use crate::registry::{Diagnostic, Rule};
-use crate::violations;
+use crate::violation::Violation;
+
+define_violation!(
+    pub struct RaisesWithMultipleStatements;
+);
+impl Violation for RaisesWithMultipleStatements {
+    #[derive_message_formats]
+    fn message(&self) -> String {
+        format!("`pytest.raises()` block should contain a single simple statement")
+    }
+}
+
+define_violation!(
+    pub struct RaisesTooBroad {
+        pub exception: String,
+    }
+);
+impl Violation for RaisesTooBroad {
+    #[derive_message_formats]
+    fn message(&self) -> String {
+        let RaisesTooBroad { exception } = self;
+        format!(
+            "`pytest.raises({exception})` is too broad, set the `match` parameter or use a more \
+             specific exception"
+        )
+    }
+}
+
+define_violation!(
+    pub struct RaisesWithoutException;
+);
+impl Violation for RaisesWithoutException {
+    #[derive_message_formats]
+    fn message(&self) -> String {
+        format!("set the expected exception in `pytest.raises()`")
+    }
+}
 
 fn is_pytest_raises(checker: &Checker, func: &Expr) -> bool {
     checker.resolve_call_path(func).map_or(false, |call_path| {
@@ -13,7 +50,7 @@ fn is_pytest_raises(checker: &Checker, func: &Expr) -> bool {
     })
 }
 
-fn is_non_trivial_with_body(body: &[Stmt]) -> bool {
+const fn is_non_trivial_with_body(body: &[Stmt]) -> bool {
     if body.len() > 1 {
         true
     } else if let Some(first_body_stmt) = body.first() {
@@ -32,7 +69,7 @@ pub fn raises_call(checker: &mut Checker, func: &Expr, args: &[Expr], keywords:
         {
             if args.is_empty() && keywords.is_empty() {
                 checker.diagnostics.push(Diagnostic::new(
-                    violations::RaisesWithoutException,
+                    RaisesWithoutException,
                     Range::from_located(func),
                 ));
             }
@@ -88,7 +125,7 @@ pub fn complex_raises(checker: &mut Checker, stmt: &Stmt, items: &[Withitem], bo
 
         if is_too_complex {
             checker.diagnostics.push(Diagnostic::new(
-                violations::RaisesWithMultipleStatements,
+                RaisesWithMultipleStatements,
                 Range::from_located(stmt),
             ));
         }
@@ -117,7 +154,7 @@ fn exception_needs_match(checker: &mut Checker, exception: &Expr) {
         }
     }) {
         checker.diagnostics.push(Diagnostic::new(
-            violations::RaisesTooBroad {
+            RaisesTooBroad {
                 exception: call_path,
             },
             Range::from_located(exception),
