@@ -2,7 +2,7 @@ use std::hash::BuildHasherDefault;
 
 use anyhow::{anyhow, bail, Result};
 use rustc_hash::FxHashMap;
-use rustpython_ast::{
+use rustpython_parser::ast::{
     Cmpop, Constant, Expr, ExprContext, ExprKind, Keyword, Stmt, StmtKind, Unaryop,
 };
 
@@ -265,12 +265,15 @@ impl UnittestAssert {
                     .get("expr")
                     .ok_or_else(|| anyhow!("Missing argument `expr`"))?;
                 let msg = args.get("msg").copied();
-                let bool = create_expr(ExprKind::Constant {
-                    value: Constant::Bool(matches!(self, UnittestAssert::True)),
-                    kind: None,
-                });
-                let expr = compare(expr, Cmpop::Is, &bool);
-                Ok(assert(&expr, msg))
+                Ok(if matches!(self, UnittestAssert::False) {
+                    let unary_expr = create_expr(ExprKind::UnaryOp {
+                        op: Unaryop::Not,
+                        operand: Box::new(create_expr(expr.node.clone())),
+                    });
+                    assert(&unary_expr, msg)
+                } else {
+                    assert(expr, msg)
+                })
             }
             UnittestAssert::Equal
             | UnittestAssert::Equals
