@@ -1,12 +1,11 @@
-use ruff_macros::derive_message_formats;
+use ruff_macros::{define_violation, derive_message_formats};
 use rustc_hash::FxHashMap;
-use rustpython_ast::{Alias, Expr, Located};
+use rustpython_parser::ast::{Alias, Expr, Located};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
 use crate::ast::types::{CallPath, Range};
 use crate::checkers::ast::Checker;
-use crate::define_violation;
 use crate::registry::Diagnostic;
 use crate::settings::hashable::HashableHashMap;
 use crate::violation::Violation;
@@ -21,6 +20,23 @@ pub struct ApiBan {
 }
 
 define_violation!(
+    /// ## What it does
+    /// Checks for banned imports.
+    ///
+    /// ## Why is this bad?
+    /// Projects may want to ensure that specific modules or module members are
+    /// not be imported or accessed.
+    ///
+    /// Security or other company policies may be a reason to impose
+    /// restrictions on importing external Python libraries. In some cases,
+    /// projects may adopt conventions around the use of certain modules or
+    /// module members that are not enforceable by the language itself.
+    ///
+    /// This rule enforces certain import conventions project-wide in an
+    /// automatic way.
+    ///
+    /// ## Options
+    /// * `flake8-tidy-imports.banned-api`
     pub struct BannedApi {
         pub name: String,
         pub message: String,
@@ -108,14 +124,14 @@ mod tests {
 
     use super::ApiBan;
     use crate::assert_yaml_snapshot;
-    use crate::linter::test_path;
     use crate::registry::Rule;
     use crate::settings::Settings;
+    use crate::test::test_path;
 
     #[test]
     fn banned_api_true_positives() -> Result<()> {
         let diagnostics = test_path(
-            Path::new("./resources/test/fixtures/flake8_tidy_imports/TID251.py"),
+            Path::new("flake8_tidy_imports/TID251.py"),
             &Settings {
                 flake8_tidy_imports: super::super::Settings {
                     banned_api: FxHashMap::from_iter([
