@@ -1,4 +1,4 @@
-use rustpython_ast::{Location, Stmt};
+use rustpython_parser::ast::{Location, Stmt};
 use rustpython_parser::lexer;
 use rustpython_parser::lexer::Tok;
 
@@ -10,7 +10,7 @@ use crate::source_code::Locator;
 /// Return `true` if a `StmtKind::ImportFrom` statement ends with a magic
 /// trailing comma.
 pub fn trailing_comma(stmt: &Stmt, locator: &Locator) -> TrailingComma {
-    let contents = locator.slice_source_code_range(&Range::from_located(stmt));
+    let contents = locator.slice(&Range::from_located(stmt));
     let mut count: usize = 0;
     let mut trailing_comma = TrailingComma::Absent;
     for (_, tok, _) in lexer::make_tokenizer(contents).flatten() {
@@ -63,7 +63,7 @@ pub fn has_comment_break(stmt: &Stmt, locator: &Locator) -> bool {
     //   # Direct comment.
     //   def f(): pass
     let mut seen_blank = false;
-    for line in locator.slice_source_code_until(stmt.location).lines().rev() {
+    for line in locator.take(stmt.location).lines().rev() {
         let line = line.trim();
         if seen_blank {
             if line.starts_with('#') {
@@ -109,7 +109,7 @@ pub fn find_splice_location(body: &[Stmt], locator: &Locator) -> Location {
     let mut splice = match_docstring_end(body).unwrap_or_default();
 
     // Find the first token that isn't a comment or whitespace.
-    let contents = locator.slice_source_code_at(splice);
+    let contents = locator.skip(splice);
     for (.., tok, end) in lexer::make_tokenizer(contents).flatten() {
         if matches!(tok, Tok::Comment(..) | Tok::Newline) {
             splice = end;
@@ -124,7 +124,7 @@ pub fn find_splice_location(body: &[Stmt], locator: &Locator) -> Location {
 #[cfg(test)]
 mod tests {
     use anyhow::Result;
-    use rustpython_ast::Location;
+    use rustpython_parser::ast::Location;
     use rustpython_parser::parser;
 
     use super::find_splice_location;
