@@ -10,9 +10,9 @@ mod tests {
     use test_case::test_case;
 
     use crate::assert_yaml_snapshot;
-    use crate::linter::test_path;
     use crate::registry::Rule;
     use crate::settings::Settings;
+    use crate::test::test_path;
 
     #[test_case(0)]
     #[test_case(3)]
@@ -20,10 +20,10 @@ mod tests {
     fn max_complexity_zero(max_complexity: usize) -> Result<()> {
         let snapshot = format!("max_complexity_{max_complexity}");
         let diagnostics = test_path(
-            Path::new("./resources/test/fixtures/mccabe/C901.py"),
+            Path::new("mccabe/C901.py"),
             &Settings {
                 mccabe: super::settings::Settings { max_complexity },
-                ..Settings::for_rules(vec![Rule::FunctionIsTooComplex])
+                ..Settings::for_rules(vec![Rule::ComplexStructure])
             },
         )?;
         assert_yaml_snapshot!(snapshot, diagnostics);
