@@ -1,8 +1,7 @@
-use ruff_macros::derive_message_formats;
-use rustpython_ast::{Expr, ExprKind};
+use ruff_macros::{define_violation, derive_message_formats};
+use rustpython_parser::ast::{Expr, ExprKind};
 
 use crate::ast::types::Range;
-use crate::define_violation;
 use crate::registry::Diagnostic;
 use crate::violation::Violation;
 
