@@ -1,9 +1,24 @@
+use once_cell::sync::Lazy;
+use regex::Regex;
+use ruff_macros::{define_violation, derive_message_formats};
+
 use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::Docstring;
 use crate::registry::Diagnostic;
-use crate::rules::pydocstyle::rules::regexes::BACKSLASH_REGEX;
-use crate::violations;
+use crate::violation::Violation;
+
+define_violation!(
+    pub struct EscapeSequenceInDocstring;
+);
+impl Violation for EscapeSequenceInDocstring {
+    #[derive_message_formats]
+    fn message(&self) -> String {
+        format!(r#"Use `r"""` if any backslashes in a docstring"#)
+    }
+}
+
+static BACKSLASH_REGEX: Lazy<Regex> = Lazy::new(|| Regex::new(r"\\[^(\r\n|\n)uN]").unwrap());
 
 /// D301
 pub fn backslashes(checker: &mut Checker, docstring: &Docstring) {
@@ -16,7 +31,7 @@ pub fn backslashes(checker: &mut Checker, docstring: &Docstring) {
 
     if BACKSLASH_REGEX.is_match(contents) {
         checker.diagnostics.push(Diagnostic::new(
-            violations::UsesRPrefixForBackslashedContent,
+            EscapeSequenceInDocstring,
             Range::from_located(docstring.expr),
         ));
     }
