@@ -1,10 +1,24 @@
-use rustpython_ast::Expr;
+use ruff_macros::{define_violation, derive_message_formats};
+use rustpython_parser::ast::Expr;
 
 use crate::ast::types::{Range, ScopeKind};
 use crate::checkers::ast::Checker;
 use crate::registry::Diagnostic;
-use crate::violations;
+use crate::violation::Violation;
 
+define_violation!(
+    pub struct UsedPriorGlobalDeclaration {
+        pub name: String,
+        pub line: usize,
+    }
+);
+impl Violation for UsedPriorGlobalDeclaration {
+    #[derive_message_formats]
+    fn message(&self) -> String {
+        let UsedPriorGlobalDeclaration { name, line } = self;
+        format!("Name `{name}` is used prior to global declaration on line {line}")
+    }
+}
 /// PLE0118
 pub fn used_prior_global_declaration(checker: &mut Checker, name: &str, expr: &Expr) {
     let globals = match &checker.current_scope().kind {
@@ -15,7 +29,7 @@ pub fn used_prior_global_declaration(checker: &mut Checker, name: &str, expr: &E
     if let Some(stmt) = globals.get(name) {
         if expr.location < stmt.location {
             checker.diagnostics.push(Diagnostic::new(
-                violations::UsedPriorGlobalDeclaration {
+                UsedPriorGlobalDeclaration {
                     name: name.to_string(),
                     line: stmt.location.row(),
                 },
