@@ -4,7 +4,7 @@ use std::fmt;
 use std::ops::Deref;
 
 use once_cell::unsync::OnceCell;
-use rustpython_ast::Location;
+use rustpython_parser::ast::Location;
 use rustpython_parser::lexer;
 use rustpython_parser::lexer::Tok;
 
@@ -97,7 +97,7 @@ impl From<&Quote> for char {
 pub struct Indentation(String);
 
 impl Indentation {
-    pub fn new(indentation: String) -> Self {
+    pub const fn new(indentation: String) -> Self {
         Self(indentation)
     }
 }
@@ -112,6 +112,10 @@ impl Indentation {
     pub fn as_str(&self) -> &str {
         self.0.as_str()
     }
+
+    pub fn as_char(&self) -> char {
+        self.0.chars().next().unwrap()
+    }
 }
 
 impl Deref for Indentation {
@@ -142,7 +146,7 @@ impl Default for LineEnding {
 }
 
 impl LineEnding {
-    pub fn as_str(&self) -> &'static str {
+    pub const fn as_str(&self) -> &'static str {
         match self {
             LineEnding::CrLf => "\r\n",
             LineEnding::Lf => "\n",
@@ -164,7 +168,7 @@ fn detect_indentation(contents: &str, locator: &Locator) -> Option<Indentation>
     for (_start, tok, end) in lexer::make_tokenizer(contents).flatten() {
         if let Tok::Indent { .. } = tok {
             let start = Location::new(end.row(), 0);
-            let whitespace = locator.slice_source_code_range(&Range::new(start, end));
+            let whitespace = locator.slice(&Range::new(start, end));
             return Some(Indentation(whitespace.to_string()));
         }
     }
@@ -175,7 +179,7 @@ fn detect_indentation(contents: &str, locator: &Locator) -> Option<Indentation>
 fn detect_quote(contents: &str, locator: &Locator) -> Option<Quote> {
     for (start, tok, end) in lexer::make_tokenizer(contents).flatten() {
         if let Tok::String { .. } = tok {
-            let content = locator.slice_source_code_range(&Range::new(start, end));
+            let content = locator.slice(&Range::new(start, end));
             if let Some(pattern) = leading_quote(content) {
                 if pattern.contains('\'') {
                     return Some(Quote::Single);
